@@ -41,7 +41,7 @@ mod watch;
 
 /// Entrypoint called by [`crate::main`]
 pub fn main() -> color_eyre::eyre::Result<()> {
-    let mut cli = Cli::parse();
+    let cli = Cli::parse();
 
     // redirect all log messages into the [debug::DebugLog]
     if has_debug_log(&cli) {
@@ -54,24 +54,28 @@ pub fn main() -> color_eyre::eyre::Result<()> {
     color_eyre::install()?;
     cli.color.write_global();
 
-    if let Err(error) = cli.command.run() {
-        eprintln!("{error}");
-        // Copied from
-        // https://doc.rust-lang.org/src/std/backtrace.rs.html#1-504, since it's private
-        fn backtrace_enabled() -> bool {
-            match env::var("RUST_LIB_BACKTRACE") {
-                Ok(s) => s != "0",
-                Err(_) => match env::var("RUST_BACKTRACE") {
+    if let Some(mut subcommand) = cli.command {
+        if let Err(error) = subcommand.run() {
+            eprintln!("{error}");
+            // Copied from
+            // https://doc.rust-lang.org/src/std/backtrace.rs.html#1-504, since it's private
+            fn backtrace_enabled() -> bool {
+                match env::var("RUST_LIB_BACKTRACE") {
                     Ok(s) => s != "0",
-                    Err(_) => false,
-                },
+                    Err(_) => match env::var("RUST_BACKTRACE") {
+                        Ok(s) => s != "0",
+                        Err(_) => false,
+                    },
+                }
+            }
+            if backtrace_enabled() {
+                eprintln!("{:#}", error.backtrace());
             }
-        }
-        if backtrace_enabled() {
-            eprintln!("{:#}", error.backtrace());
-        }
 
-        exit(1)
+            exit(1)
+        }
+    } else {
+        Cli::command().print_help()?;
     }
 
     Ok(())
@@ -80,7 +84,7 @@ pub fn main() -> color_eyre::eyre::Result<()> {
 #[derive(Parser, Debug, Clone)]
 struct Cli {
     #[command(subcommand)]
-    command: Command,
+    command: Option<Command>,
     #[command(flatten)]
     color: colorchoice_clap::Color,
 }
@@ -333,16 +337,7 @@ impl Command {
     }
 
     fn list_targets(&self) -> std::result::Result<(), anyhow::Error> {
-        let res: Result<std::string::String, anyhow::Error> = Ok(match self {
-            Command::ListTargets => Target::names().join("\n"),
-            _ => unreachable!(),
-        });
-
-        match res {
-            Ok(s) => println!("{s}"),
-            Err(_) => unreachable!(),
-        }
-
+        println!("{}", Target::names().join("\n"));
         Ok(())
     }
 
@@ -542,10 +537,10 @@ impl Command {
 fn has_debug_log(cli: &Cli) -> bool {
     matches!(
         cli.command,
-        Command::Compile {
+        Some(Command::Compile {
             debug_log: Some(_),
             ..
-        }
+        })
     )
 }
 
@@ -756,7 +751,7 @@ sort full
         )
         .unwrap();
 
-        assert_snapshot!(String::from_utf8(output).unwrap().trim(), @r"
+        assert_snapshot!(String::from_utf8(output).unwrap().trim(), @r#"
         name: Project
         stmts:
         - VarDef:
@@ -767,23 +762,27 @@ sort full
                 exprs:
                 - FuncCall:
                     name:
-                      Ident: from
+                      Ident:
+                      - from
                       span: 1:0-4
                     args:
-                    - Ident: x
+                    - Ident:
+                      - x
                       span: 1:5-6
                   span: 1:0-6
                 - FuncCall:
                     name:
-                      Ident: select
+                      Ident:
+                      - select
                       span: 1:9-15
                     args:
-                    - Ident: y
+                    - Ident:
+                      - y
                       span: 1:16-17
                   span: 1:9-17
               span: 1:0-17
           span: 1:0-17
-        ");
+        "#);
     }
     #[test]
     fn lex() {
