@@ -13,11 +13,11 @@ use walkdir::WalkDir;
 #[cfg(not(windows))] // Windows has slightly different output (e.g. `prqlc.exe`), so we exclude.
 #[test]
 fn help() {
-    assert_cmd_snapshot!(prqlc_command().arg("--help"), @r#"
+    assert_cmd_snapshot!(prqlc_command().arg("--help"), @r"
     success: true
     exit_code: 0
     ----- stdout -----
-    Usage: prqlc [OPTIONS] <COMMAND>
+    Usage: prqlc [OPTIONS] [COMMAND]
 
     Commands:
       parse             Parse into PL AST
@@ -39,7 +39,36 @@ fn help() {
       -V, --version       Print version
 
     ----- stderr -----
-    "#);
+    ");
+
+    // without arguments
+    assert_cmd_snapshot!(prqlc_command(), @r"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+    Usage: prqlc [OPTIONS] [COMMAND]
+
+    Commands:
+      parse             Parse into PL AST
+      lex               Lex into Lexer Representation
+      fmt               Parse & generate PRQL code back
+      collect           Parse the whole project and collect it into a single PRQL source file
+      debug             Commands for meant for debugging, prone to change
+      experimental      Experimental commands are prone to change
+      compile           Parse, resolve, lower into RQ & compile to SQL
+      watch             Watch a directory and compile .prql files to .sql files
+      list-targets      Show available compile target names
+      shell-completion  Print a shell completion for supported shells
+      help              Print this message or the help of the given subcommand(s)
+
+    Options:
+          --color <WHEN>  Controls when to use color [default: auto] [possible values: auto, always,
+                          never]
+      -h, --help          Print help
+      -V, --version       Print version
+
+    ----- stderr -----
+    ");
 }
 
 #[test]
@@ -394,7 +423,7 @@ fn compare_directories(dir1: &Path, dir2: &Path) {
 fn debug() {
     assert_cmd_snapshot!(prqlc_command()
         .args(["debug", "lineage"])
-        .pass_stdin("from tracks | select {artist, album}"), @r###"
+        .pass_stdin("from tracks | select {artist, album}"), @r#"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -405,29 +434,29 @@ fn debug() {
           name:
           - tracks
           - artist
-          target_id: 120
+          target_id: 117
           target_name: null
         - !Single
           name:
           - tracks
           - album
-          target_id: 121
+          target_id: 118
           target_name: null
         inputs:
-        - id: 118
+        - id: 115
           name: tracks
           table:
           - default_db
           - tracks
     nodes:
-    - id: 118
+    - id: 115
       kind: Ident
       span: 1:0-11
       ident: !Ident
       - default_db
       - tracks
-      parent: 123
-    - id: 120
+      parent: 120
+    - id: 117
       kind: Ident
       span: 1:22-28
       ident: !Ident
@@ -435,9 +464,9 @@ fn debug() {
       - tracks
       - artist
       targets:
-      - 118
-      parent: 122
-    - id: 121
+      - 115
+      parent: 119
+    - id: 118
       kind: Ident
       span: 1:30-35
       ident: !Ident
@@ -445,21 +474,21 @@ fn debug() {
       - tracks
       - album
       targets:
-      - 118
-      parent: 122
-    - id: 122
+      - 115
+      parent: 119
+    - id: 119
       kind: Tuple
       span: 1:21-36
       children:
-      - 120
-      - 121
-      parent: 123
-    - id: 123
+      - 117
+      - 118
+      parent: 120
+    - id: 120
       kind: 'TransformCall: Select'
       span: 1:14-36
       children:
-      - 118
-      - 122
+      - 115
+      - 119
     ast:
       name: Project
       stmts:
@@ -471,21 +500,26 @@ fn debug() {
               exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                    - from
                     span: 1:0-4
                   args:
-                  - Ident: tracks
+                  - Ident:
+                    - tracks
                     span: 1:5-11
                 span: 1:0-11
               - FuncCall:
                   name:
-                    Ident: select
+                    Ident:
+                    - select
                     span: 1:14-20
                   args:
                   - Tuple:
-                    - Ident: artist
+                    - Ident:
+                      - artist
                       span: 1:22-28
-                    - Ident: album
+                    - Ident:
+                      - album
                       span: 1:30-35
                     span: 1:21-36
                 span: 1:14-36
@@ -493,7 +527,7 @@ fn debug() {
         span: 1:0-36
 
     ----- stderr -----
-    "###);
+    "#);
 
     // Don't test the output of this, since on one min-versions check it had
     // different results, and didn't repro on Mac. It having different results
