@@ -9,6 +9,7 @@
 use anyhow::{anyhow, Error, Result};
 use cargo_metadata::{DepKindInfo, DependencyKind, MetadataCommand, Package, PackageId};
 use derive_builder::Builder as DeriveBuilder;
+use getset::Setters;
 use regex::Regex;
 use std::env;
 use vergen_lib::{
@@ -104,7 +105,7 @@ use vergen_lib::{
 /// # }
 /// ```
 ///
-#[derive(Clone, Copy, Debug, DeriveBuilder, PartialEq)]
+#[derive(Clone, Copy, Debug, DeriveBuilder, PartialEq, Setters)]
 #[allow(clippy::struct_excessive_bools)]
 pub struct Cargo {
     /// Emit the DEBUG value set by cargo
@@ -154,6 +155,7 @@ pub struct Cargo {
     /// ```
     ///
     #[builder(default = "None", setter(into))]
+    #[getset(set = "pub")]
     name_filter: Option<&'static str>,
     /// Add a [`DependencyKind`](cargo_metadata::DependencyKind) filter for cargo dependencies
     ///
@@ -162,6 +164,7 @@ pub struct Cargo {
     /// ```
     ///
     #[builder(default = "None", setter(into))]
+    #[getset(set = "pub")]
     dep_kind_filter: Option<DependencyKind>,
 }
 
@@ -263,27 +266,6 @@ impl Cargo {
             .collect();
         Ok(results.join(","))
     }
-
-    /// Add a name [`Regex`](regex::Regex) filter for cargo dependencies
-    ///
-    /// ```text
-    /// cargo:rustc-env=VERGEN_CARGO_DEPENDENCIES=<deps_filtered_by_name>
-    /// ```
-    ///
-    pub fn set_name_filter(&mut self, val: Option<&'static str>) -> &mut Self {
-        self.name_filter = val;
-        self
-    }
-    /// Add a [`DependencyKind`](cargo_metadata::DependencyKind) filter for cargo dependencies
-    ///
-    /// ```text
-    /// cargo:rustc-env=VERGEN_CARGO_DEPENDENCIES=<deps_filtered_by_kind>
-    /// ```
-    ///
-    pub fn set_dep_kind_filter(&mut self, val: Option<DependencyKind>) -> &mut Self {
-        self.dep_kind_filter = val;
-        self
-    }
 }
 
 impl AddEntries for Cargo {
