@@ -22,6 +22,7 @@ use std::{
     hash::Hash,
     io::{self, Write},
     ops::Range,
+    ops::RangeInclusive,
 };
 use unicode_width::UnicodeWidthChar;
 
@@ -89,6 +90,34 @@ impl<Id: fmt::Debug + Hash + PartialEq + Eq + ToOwned> Span for (Id, Range<usize
     }
 }
 
+impl Span for RangeInclusive<usize> {
+    type SourceId = ();
+
+    fn source(&self) -> &Self::SourceId {
+        &()
+    }
+    fn start(&self) -> usize {
+        *self.start()
+    }
+    fn end(&self) -> usize {
+        *self.end() + 1
+    }
+}
+
+impl<Id: fmt::Debug + Hash + PartialEq + Eq + ToOwned> Span for (Id, RangeInclusive<usize>) {
+    type SourceId = Id;
+
+    fn source(&self) -> &Self::SourceId {
+        &self.0
+    }
+    fn start(&self) -> usize {
+        *self.1.start()
+    }
+    fn end(&self) -> usize {
+        *self.1.end() + 1
+    }
+}
+
 /// A type that represents the way a label should be displayed.
 #[derive(Clone, Debug, Hash, PartialEq, Eq)]
 struct LabelDisplay {
@@ -173,27 +202,25 @@ pub struct Report<'a, S: Span = Range<usize>> {
     kind: ReportKind<'a>,
     code: Option<String>,
     msg: Option<String>,
-    note: Option<String>,
+    notes: Vec<String>,
     help: Option<String>,
-    location: (<S::SourceId as ToOwned>::Owned, usize),
+    span: S,
     labels: Vec<Label<S>>,
     config: Config,
 }
 
 impl<S: Span> Report<'_, S> {
     /// Begin building a new [`Report`].
-    pub fn build<Id: Into<<S::SourceId as ToOwned>::Owned>>(
-        kind: ReportKind,
-        src_id: Id,
-        offset: usize,
-    ) -> ReportBuilder<S> {
+    ///
+    /// The span is the primary location at which the error should be reported.
+    pub fn build(kind: ReportKind, span: S) -> ReportBuilder<S> {
         ReportBuilder {
             kind,
             code: None,
             msg: None,
-            note: None,
+            notes: vec![],
             help: None,
-            location: (src_id.into(), offset),
+            span,
             labels: Vec::new(),
             config: Config::default(),
         }
@@ -219,7 +246,7 @@ impl<'a, S: Span> fmt::Debug for Report<'a, S> {
             .field("kind", &self.kind)
             .field("code", &self.code)
             .field("msg", &self.msg)
-            .field("note", &self.note)
+            .field("notes", &self.notes)
             .field("help", &self.help)
             .field("config", &self.config)
             .finish()
@@ -256,9 +283,9 @@ pub struct ReportBuilder<'a, S: Span> {
     kind: ReportKind<'a>,
     code: Option<String>,
     msg: Option<String>,
-    note: Option<String>,
+    notes: Vec<String>,
     help: Option<String>,
-    location: (<S::SourceId as ToOwned>::Owned, usize),
+    span: S,
     labels: Vec<Label<S>>,
     config: Config,
 }
@@ -283,12 +310,24 @@ impl<'a, S: Span> ReportBuilder<'a, S> {
 
     /// Set the note of this report.
     pub fn set_note<N: ToString>(&mut self, note: N) {
-        self.note = Some(note.to_string());
+        self.notes = vec![note.to_string()];
+    }
+
+    /// Adds a note to this report.
+    pub fn add_note<N: ToString>(&mut self, note: N) {
+        self.notes.push(note.to_string());
+    }
+
+    /// Removes all notes in this report.
+    pub fn with_notes<N: IntoIterator<Item = impl ToString>>(&mut self, notes: N) {
+        for note in notes {
+            self.add_note(note)
+        }
     }
 
     /// Set the note of this report.
     pub fn with_note<N: ToString>(mut self, note: N) -> Self {
-        self.set_note(note);
+        self.add_note(note);
         self
     }
 
@@ -341,9 +380,9 @@ impl<'a, S: Span> ReportBuilder<'a, S> {
             kind: self.kind,
             code: self.code,
             msg: self.msg,
-            note: self.note,
+            notes: self.notes,
             help: self.help,
-            location: self.location,
+            span: self.span,
             labels: self.labels,
             config: self.config,
         }
@@ -356,7 +395,7 @@ impl<'a, S: Span> fmt::Debug for ReportBuilder<'a, S> {
             .field("kind", &self.kind)
             .field("code", &self.code)
             .field("msg", &self.msg)
-            .field("note", &self.note)
+            .field("notes", &self.notes)
             .field("help", &self.help)
             .field("config", &self.config)
             .finish()
@@ -412,63 +451,63 @@ impl Config {
     /// The alternative to this is to insert crossing characters. However, these interact poorly with label colours.
     ///
     /// If unspecified, this defaults to [`false`].
-    pub fn with_cross_gap(mut self, cross_gap: bool) -> Self {
+    pub const fn with_cross_gap(mut self, cross_gap: bool) -> Self {
         self.cross_gap = cross_gap;
         self
     }
     /// Where should inline labels attach to their spans?
     ///
     /// If unspecified, this defaults to [`LabelAttach::Middle`].
-    pub fn with_label_attach(mut self, label_attach: LabelAttach) -> Self {
+    pub const fn with_label_attach(mut self, label_attach: LabelAttach) -> Self {
         self.label_attach = label_attach;
         self
     }
     /// Should the report remove gaps to minimise used space?
     ///
     /// If unspecified, this defaults to [`false`].
-    pub fn with_compact(mut self, compact: bool) -> Self {
+    pub const fn with_compact(mut self, compact: bool) -> Self {
         self.compact = compact;
         self
     }
     /// Should underlines be used for label span where possible?
     ///
     /// If unspecified, this defaults to [`true`].
-    pub fn with_underlines(mut self, underlines: bool) -> Self {
+    pub const fn with_underlines(mut self, underlines: bool) -> Self {
         self.underlines = underlines;
         self
     }
     /// Should arrows be used to point to the bounds of multi-line spans?
     ///
     /// If unspecified, this defaults to [`true`].
-    pub fn with_multiline_arrows(mut self, multiline_arrows: bool) -> Self {
+    pub const fn with_multiline_arrows(mut self, multiline_arrows: bool) -> Self {
         self.multiline_arrows = multiline_arrows;
         self
     }
     /// Should colored output should be enabled?
     ///
     /// If unspecified, this defaults to [`true`].
-    pub fn with_color(mut self, color: bool) -> Self {
+    pub const fn with_color(mut self, color: bool) -> Self {
         self.color = color;
         self
     }
     /// How many characters width should tab characters be?
     ///
     /// If unspecified, this defaults to `4`.
-    pub fn with_tab_width(mut self, tab_width: usize) -> Self {
+    pub const fn with_tab_width(mut self, tab_width: usize) -> Self {
         self.tab_width = tab_width;
         self
     }
     /// What character set should be used to display dynamic elements such as boxes and arrows?
     ///
     /// If unspecified, this defaults to [`CharSet::Unicode`].
-    pub fn with_char_set(mut self, char_set: CharSet) -> Self {
+    pub const fn with_char_set(mut self, char_set: CharSet) -> Self {
         self.char_set = char_set;
         self
     }
     /// Should this report use byte spans instead of char spans?
     ///
     /// If unspecified, this defaults to 'false'
-    pub fn with_index_type(mut self, index_type: IndexType) -> Self {
+    pub const fn with_index_type(mut self, index_type: IndexType) -> Self {
         self.index_type = index_type;
         self
     }
@@ -510,10 +549,9 @@ impl Config {
             _ => (c, c.width().unwrap_or(1)),
         }
     }
-}
 
-impl Default for Config {
-    fn default() -> Self {
+    /// Create a new, default config.
+    pub const fn new() -> Self {
         Self {
             cross_gap: true,
             label_attach: LabelAttach::Middle,
@@ -528,6 +566,12 @@ impl Default for Config {
     }
 }
 
+impl Default for Config {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 #[test]
 #[should_panic]
 #[allow(clippy::reversed_empty_ranges)]
