@@ -6,6 +6,8 @@
 #![forbid(unsafe_code)]
 // Maintains semver compatibility for older Rust versions
 #![allow(clippy::manual_strip)]
+// This lint is overly pedantic and annoying
+#![allow(clippy::needless_lifetimes)]
 
 mod formatter;
 mod indentation;
@@ -15,7 +17,7 @@ mod tokenizer;
 
 /// Formats whitespace in a SQL string to make it easier to read.
 /// Optionally replaces parameter placeholders with `params`.
-pub fn format(query: &str, params: &QueryParams, options: FormatOptions) -> String {
+pub fn format(query: &str, params: &QueryParams, options: &FormatOptions) -> String {
     let named_placeholders = matches!(params, QueryParams::Named(_));
 
     let tokens = tokenizer::tokenize(query, named_placeholders);
@@ -23,8 +25,8 @@ pub fn format(query: &str, params: &QueryParams, options: FormatOptions) -> Stri
 }
 
 /// Options for controlling how the library formats SQL
-#[derive(Debug, Clone, Copy)]
-pub struct FormatOptions {
+#[derive(Debug, Clone)]
+pub struct FormatOptions<'a> {
     /// Controls the type and length of indentation to use
     ///
     /// Default: 2 spaces
@@ -32,19 +34,24 @@ pub struct FormatOptions {
     /// When set, changes reserved keywords to ALL CAPS
     ///
     /// Default: false
-    pub uppercase: bool,
+    pub uppercase: Option<bool>,
     /// Controls the number of line breaks after a query
     ///
     /// Default: 1
     pub lines_between_queries: u8,
+    /// Ignore case conversion for specified strings in the array.
+    ///
+    /// Default: None
+    pub ignore_case_convert: Option<Vec<&'a str>>,
 }
 
-impl Default for FormatOptions {
+impl<'a> Default for FormatOptions<'a> {
     fn default() -> Self {
         FormatOptions {
             indent: Indent::Spaces(2),
-            uppercase: false,
+            uppercase: None,
             lines_between_queries: 1,
+            ignore_case_convert: None,
         }
     }
 }
@@ -55,19 +62,14 @@ pub enum Indent {
     Tabs,
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Default)]
 pub enum QueryParams {
     Named(Vec<(String, String)>),
     Indexed(Vec<String>),
+    #[default]
     None,
 }
 
-impl Default for QueryParams {
-    fn default() -> Self {
-        QueryParams::None
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -89,7 +91,7 @@ mod tests {
                 Table1;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -104,7 +106,7 @@ mod tests {
               schema2;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -120,7 +122,7 @@ mod tests {
               Table1;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -139,7 +141,7 @@ mod tests {
               foo;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -167,7 +169,7 @@ mod tests {
               );"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -197,7 +199,7 @@ mod tests {
               5;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -210,7 +212,7 @@ mod tests {
               5, 10;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -226,7 +228,7 @@ mod tests {
               bar;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -239,7 +241,7 @@ mod tests {
               5 OFFSET 8;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -252,7 +254,7 @@ mod tests {
               5, 10;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -271,7 +273,7 @@ mod tests {
               and b = 3"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -296,7 +298,7 @@ mod tests {
               a > b"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -317,7 +319,35 @@ mod tests {
               INNER JOIN orders ON customers.customer_id = orders.customer_id;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_formats_select_query_with_non_standard_join() {
+        let input = indoc!(
+            "
+            SELECT customer_id.from, COUNT(order_id) AS total FROM customers
+            INNER ANY JOIN orders ON customers.customer_id = orders.customer_id
+            LEFT
+            SEMI JOIN foo ON foo.id = customers.id
+            PASTE
+            JOIN bar
+            ;"
+        );
+        let options = FormatOptions::default();
+        let expected = indoc!(
+            "
+            SELECT
+              customer_id.from,
+              COUNT(order_id) AS total
+            FROM
+              customers
+              INNER ANY JOIN orders ON customers.customer_id = orders.customer_id
+              LEFT SEMI JOIN foo ON foo.id = customers.id
+              PASTE JOIN bar;"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -348,7 +378,7 @@ mod tests {
               1 = 2;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -367,7 +397,7 @@ mod tests {
         );
         let options = FormatOptions::default();
 
-        assert_eq!(format(input, &QueryParams::None, options), input);
+        assert_eq!(format(input, &QueryParams::None, &options), input);
     }
 
     #[test]
@@ -382,7 +412,7 @@ mod tests {
               (12, -123.4, 'Skagen 2111', 'Stv');"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -395,7 +425,7 @@ mod tests {
               (a + b * (c - NOW()));"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -433,7 +463,7 @@ mod tests {
               );"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -451,7 +481,7 @@ mod tests {
               CustomerName = 'Alfreds Futterkiste';"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -467,7 +497,7 @@ mod tests {
               AND Phone = 5002132;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -475,7 +505,7 @@ mod tests {
         let input = "DROP TABLE IF EXISTS admin_role;";
         let options = FormatOptions::default();
 
-        assert_eq!(format(input, &QueryParams::None, options), input);
+        assert_eq!(format(input, &QueryParams::None, &options), input);
     }
 
     #[test]
@@ -488,7 +518,7 @@ mod tests {
               count("
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -506,7 +536,7 @@ mod tests {
               /*Comment"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -528,7 +558,7 @@ mod tests {
               ) AS order_summary"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -546,7 +576,7 @@ mod tests {
               blah"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -562,7 +592,7 @@ mod tests {
             )"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -570,7 +600,7 @@ mod tests {
         let input = "((foo = 'bar'))";
         let options = FormatOptions::default();
 
-        assert_eq!(format(input, &QueryParams::None, options), input);
+        assert_eq!(format(input, &QueryParams::None, &options), input);
     }
 
     #[test]
@@ -587,7 +617,7 @@ mod tests {
         ];
         let options = FormatOptions::default();
         for input in &inputs {
-            assert_eq!(&format(input, &QueryParams::None, options), input);
+            assert_eq!(&format(input, &QueryParams::None, &options), input);
         }
     }
 
@@ -605,7 +635,7 @@ mod tests {
         ];
         let options = FormatOptions::default();
         for input in &inputs {
-            assert_eq!(&format(input, &QueryParams::None, options), input);
+            assert_eq!(&format(input, &QueryParams::None, &options), input);
         }
     }
 
@@ -622,7 +652,7 @@ mod tests {
         ];
         let options = FormatOptions::default();
         for input in &inputs {
-            assert_eq!(&format(input, &QueryParams::None, options), input);
+            assert_eq!(&format(input, &QueryParams::None, &options), input);
         }
     }
 
@@ -636,7 +666,7 @@ mod tests {
         ];
         let options = FormatOptions::default();
         for (input, output) in &strings {
-            assert_eq!(&format(input, &QueryParams::None, options), output);
+            assert_eq!(&format(input, &QueryParams::None, &options), output);
         }
     }
 
@@ -645,7 +675,7 @@ mod tests {
         let inputs = ["\"foo JOIN bar\"", "'foo JOIN bar'", "`foo JOIN bar`"];
         let options = FormatOptions::default();
         for input in &inputs {
-            assert_eq!(&format(input, &QueryParams::None, options), input);
+            assert_eq!(&format(input, &QueryParams::None, &options), input);
         }
     }
 
@@ -658,17 +688,18 @@ mod tests {
             r#"'foo '' JOIN bar'"#,
             r#"'two households"'"#,
             r#"'two households'''"#,
+            r#"E'alice'''"#,
         ];
         let options = FormatOptions::default();
         for input in &inputs {
-            assert_eq!(&format(input, &QueryParams::None, options), input);
+            assert_eq!(&format(input, &QueryParams::None, &options), input);
         }
     }
 
     #[test]
     fn it_formats_postgres_specific_operators() {
         let strings = [
-            ("column::int", "column :: int"),
+            ("column::int", "column::int"),
             ("v->2", "v -> 2"),
             ("v->>2", "v ->> 2"),
             ("foo ~~ 'hello'", "foo ~~ 'hello'"),
@@ -681,7 +712,7 @@ mod tests {
         ];
         let options = FormatOptions::default();
         for (input, output) in &strings {
-            assert_eq!(&format(input, &QueryParams::None, options), output);
+            assert_eq!(&format(input, &QueryParams::None, &options), output);
         }
     }
 
@@ -694,7 +725,7 @@ mod tests {
         ];
         let options = FormatOptions::default();
         for (input, output) in &strings {
-            assert_eq!(&format(input, &QueryParams::None, options), output);
+            assert_eq!(&format(input, &QueryParams::None, &options), output);
         }
 
         let input = indoc!(
@@ -717,7 +748,7 @@ mod tests {
               Table2;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -733,14 +764,14 @@ mod tests {
               table;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
     fn it_converts_keywords_to_uppercase_when_option_passed_in() {
         let input = "select distinct * frOM foo left join bar WHERe cola > 1 and colb = 3";
         let options = FormatOptions {
-            uppercase: true,
+            uppercase: Some(true),
             ..FormatOptions::default()
         };
         let expected = indoc!(
@@ -755,7 +786,7 @@ mod tests {
               AND colb = 3"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -778,7 +809,7 @@ mod tests {
               bar;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -803,7 +834,7 @@ mod tests {
             );"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -811,7 +842,7 @@ mod tests {
         let input = "CREATE TABLE items (a INT PRIMARY KEY, b TEXT);";
         let options = FormatOptions::default();
 
-        assert_eq!(format(input, &QueryParams::None, options), input);
+        assert_eq!(format(input, &QueryParams::None, &options), input);
     }
 
     #[test]
@@ -829,7 +860,7 @@ mod tests {
             );"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -845,7 +876,7 @@ mod tests {
               (12, -123.4, 'Skagen 2111', 'Stv');"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -860,7 +891,7 @@ mod tests {
               supplier_name char(100) NOT NULL;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -875,7 +906,7 @@ mod tests {
               supplier_name VARCHAR(100) NOT NULL;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -883,7 +914,7 @@ mod tests {
         let inputs = ["[foo JOIN bar]", "[foo ]] JOIN bar]"];
         let options = FormatOptions::default();
         for input in &inputs {
-            assert_eq!(&format(input, &QueryParams::None, options), input);
+            assert_eq!(&format(input, &QueryParams::None, &options), input);
         }
     }
 
@@ -903,7 +934,7 @@ mod tests {
               @[var name];"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -930,7 +961,7 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Named(params), options),
+            format(input, &QueryParams::Named(params), &options),
             expected
         );
     }
@@ -951,7 +982,7 @@ mod tests {
               :[var name];"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -987,7 +1018,7 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Named(params), options),
+            format(input, &QueryParams::Named(params), &options),
             expected
         );
     }
@@ -1004,7 +1035,7 @@ mod tests {
               ?;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1025,11 +1056,11 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Indexed(params), options),
+            format(input, &QueryParams::Indexed(params), &options),
             expected
         );
 
-        format("?62666666121266666612", &QueryParams::None, options);
+        format("?62666666121266666612", &QueryParams::None, &options);
     }
 
     #[test]
@@ -1050,7 +1081,7 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Indexed(params), options),
+            format(input, &QueryParams::Indexed(params), &options),
             expected
         );
     }
@@ -1066,7 +1097,7 @@ mod tests {
               $2;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1081,7 +1112,7 @@ mod tests {
               $bar;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1106,7 +1137,7 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Indexed(params), options),
+            format(input, &QueryParams::Indexed(params), &options),
             expected
         );
     }
@@ -1131,7 +1162,7 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Named(params), options),
+            format(input, &QueryParams::Named(params), &options),
             expected
         );
     }
@@ -1155,7 +1186,7 @@ mod tests {
         );
 
         assert_eq!(
-            format(input, &QueryParams::Indexed(params), options),
+            format(input, &QueryParams::Indexed(params), &options),
             expected
         );
     }
@@ -1174,7 +1205,7 @@ mod tests {
               CROSS JOIN t2 on t.id = t2.id_t"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1191,7 +1222,7 @@ mod tests {
               CROSS APPLY fn(t.id)"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1207,7 +1238,7 @@ mod tests {
               t"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1220,7 +1251,7 @@ mod tests {
               N'value'"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1237,7 +1268,7 @@ mod tests {
               OUTER APPLY fn(t.id)"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1252,7 +1283,7 @@ mod tests {
               2 ROWS ONLY;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1269,7 +1300,7 @@ mod tests {
             END;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1292,7 +1323,7 @@ mod tests {
               table"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1310,7 +1341,7 @@ mod tests {
             END;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1325,7 +1356,7 @@ mod tests {
             end;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1341,7 +1372,7 @@ mod tests {
               table1;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1356,7 +1387,7 @@ mod tests {
               b --comment"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1377,7 +1408,7 @@ mod tests {
             ;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1396,7 +1427,7 @@ mod tests {
               b"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1411,7 +1442,7 @@ mod tests {
               )"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1425,7 +1456,7 @@ mod tests {
               ()"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1433,7 +1464,7 @@ mod tests {
         let input = ";";
         let options = FormatOptions::default();
 
-        assert_eq!(format(input, &QueryParams::None, options), input);
+        assert_eq!(format(input, &QueryParams::None, &options), input);
     }
 
     #[test]
@@ -1442,7 +1473,7 @@ mod tests {
         let options = FormatOptions::default();
         let expected = "SELECT\n  'главная'";
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1460,7 +1491,7 @@ mod tests {
               t"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1479,7 +1510,7 @@ mod tests {
             LANGUAGE plpgsql;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 
     #[test]
@@ -1502,6 +1533,367 @@ mod tests {
             LANGUAGE plpgsql;"
         );
 
-        assert_eq!(format(input, &QueryParams::None, options), expected);
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_handles_comments_correctly() {
+        let input = indoc!(
+            "
+                -- 创建一个外部表，存储销售数据
+            CREATE EXTERNAL TABLE IF NOT EXISTS sales_data (
+                -- 唯一标识订单ID
+                order_id BIGINT COMMENT 'Unique identifier for the order',
+
+                -- 客户ID
+                customer_id BIGINT COMMENT 'Unique identifier for the customer',
+            )
+            COMMENT 'Sales data table for storing transaction records';
+
+            -- 按销售日期和城市进行分区
+            PARTITIONED BY (
+                sale_year STRING COMMENT 'Year of the sale',
+                sale_month STRING COMMENT 'Month of the sale'
+            )
+
+            -- 设置数据存储位置
+            LOCATION '/user/hive/warehouse/sales_data'
+
+            -- 使用 ORC 存储格式
+            STORED AS ORC
+
+            -- 设置表的行格式
+            ROW FORMAT DELIMITED
+            FIELDS TERMINATED BY ','
+            LINES TERMINATED BY '\n'
+
+            -- 设置表属性
+            TBLPROPERTIES (
+                'orc.compress' = 'SNAPPY',          -- 使用SNAPPY压缩
+                'transactional' = 'true',           -- 启用事务支持
+                'orc.create.index' = 'true',        -- 创建索引
+                'skip.header.line.count' = '1',     -- 跳过CSV文件的第一行
+                'external.table.purge' = 'true'     -- 在删除表时自动清理数据
+            );
+
+            -- 自动加载数据到 Hive 分区中
+            ALTER TABLE sales_data
+            ADD PARTITION (sale_year = '2024', sale_month = '08')
+            LOCATION '/user/hive/warehouse/sales_data/2024/08';"
+        );
+        let options = FormatOptions {
+            indent: Indent::Spaces(4),
+            ..Default::default()
+        };
+        let expected = indoc!(
+            "
+            -- 创建一个外部表，存储销售数据
+            CREATE EXTERNAL TABLE IF NOT EXISTS sales_data (
+                -- 唯一标识订单ID
+                order_id BIGINT COMMENT 'Unique identifier for the order',
+                -- 客户ID
+                customer_id BIGINT COMMENT 'Unique identifier for the customer',
+            ) COMMENT 'Sales data table for storing transaction records';
+            -- 按销售日期和城市进行分区
+            PARTITIONED BY (
+                sale_year STRING COMMENT 'Year of the sale',
+                sale_month STRING COMMENT 'Month of the sale'
+            )
+            -- 设置数据存储位置
+            LOCATION '/user/hive/warehouse/sales_data'
+            -- 使用 ORC 存储格式
+            STORED AS ORC
+            -- 设置表的行格式
+            ROW FORMAT DELIMITED FIELDS TERMINATED BY ',' LINES TERMINATED BY '\n'
+            -- 设置表属性
+            TBLPROPERTIES (
+                'orc.compress' = 'SNAPPY',  -- 使用SNAPPY压缩
+                'transactional' = 'true',  -- 启用事务支持
+                'orc.create.index' = 'true',  -- 创建索引
+                'skip.header.line.count' = '1',  -- 跳过CSV文件的第一行
+                'external.table.purge' = 'true' -- 在删除表时自动清理数据
+            );
+            -- 自动加载数据到 Hive 分区中
+            ALTER TABLE
+                sales_data
+            ADD
+                PARTITION (sale_year = '2024', sale_month = '08') LOCATION '/user/hive/warehouse/sales_data/2024/08';"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_recognizes_returning_clause() {
+        let input = indoc!(
+            "
+          INSERT INTO
+            users (name, email)
+          VALUES
+            ($1, $2) RETURNING name,
+            email"
+        );
+        let options = FormatOptions::default();
+        let expected = indoc!(
+            "
+          INSERT INTO
+            users (name, email)
+          VALUES
+            ($1, $2)
+          RETURNING
+            name,
+            email"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_recognizes_on_update_clause() {
+        let input = indoc!(
+            "CREATE TABLE a (b integer REFERENCES c (id) ON                                     UPDATE RESTRICT, other integer);"
+        );
+        let options = FormatOptions::default();
+        let expected = indoc!(
+            "
+          CREATE TABLE a (
+            b integer REFERENCES c (id) ON UPDATE RESTRICT,
+            other integer
+          );"
+        );
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_formats_except_on_columns() {
+        let input = indoc!(
+            "SELECT table_0.* EXCEPT (profit),
+                    details.* EXCEPT (item_id),
+                    table_0.profit
+        FROM  table_0"
+        );
+        let options = FormatOptions {
+            indent: Indent::Spaces(4),
+            ..Default::default()
+        };
+        let expected = indoc!(
+            "
+            SELECT
+                table_0.* EXCEPT (profit),
+                details.* EXCEPT (item_id),
+                table_0.profit
+            FROM
+                table_0"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_uses_given_ignore_case_convert_config() {
+        let input = "select count(*),Column1 from Table1;";
+        let options = FormatOptions {
+            uppercase: Some(true),
+            ignore_case_convert: Some(vec!["from"]),
+            ..FormatOptions::default()
+        };
+        let expected = indoc!(
+            "
+            SELECT
+              count(*),
+              Column1
+            from
+              Table1;"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_recognizes_fmt_off() {
+        let input = indoc!(
+            "SELECT              *     FROM   sometable
+            WHERE
+            -- comment test here
+                 -- fmt: off
+                first_key.second_key = 1
+                                -- json:first_key.second_key = 1
+                      -- fmt: on
+                AND
+                   -- fm1t: off
+                first_key.second_key = 1
+                                    --  json:first_key.second_key = 1
+                -- fmt:on"
+        );
+        let options = FormatOptions {
+            indent: Indent::Spaces(4),
+            ..Default::default()
+        };
+        let expected = indoc!(
+            "
+            SELECT
+                *
+            FROM
+                sometable
+            WHERE
+                -- comment test here
+                first_key.second_key = 1
+                                -- json:first_key.second_key = 1
+                AND
+                -- fm1t: off
+                first_key.second_key = 1
+                --  json:first_key.second_key = 1"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_converts_keywords_to_lowercase_when_option_passed_in() {
+        let input = "select distinct * frOM foo left join bar WHERe cola > 1 and colb = 3";
+        let options = FormatOptions {
+            uppercase: Some(false),
+            ..FormatOptions::default()
+        };
+        let expected = indoc!(
+            "
+            select
+              distinct *
+            from
+              foo
+              left join bar
+            where
+              cola > 1
+              and colb = 3"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+
+    #[test]
+    fn it_converts_keywords_nothing_when_no_option_passed_in() {
+        let input = "select distinct * frOM foo left join bar WHERe cola > 1 and colb = 3";
+        let options = FormatOptions {
+            uppercase: None,
+            ..FormatOptions::default()
+        };
+        let expected = indoc!(
+            "
+            select
+              distinct *
+            frOM
+              foo
+              left join bar
+            WHERe
+              cola > 1
+              and colb = 3"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+    #[test]
+    fn it_correctly_parses_all_operators() {
+        let operators = [
+            "!!", "!~~*", "!~~", "!~*", "!~", "##", "#>>", "#>", "#-", "&<|", "&<", "&>", "&&",
+            "*<>", "*<=", "*>=", "*>", "*=", "*<", "<<|", "<<=", "<<", "<->", "<@", "<^", "<=",
+            "<>", "<", ">=", ">>=", ">>", ">^", "->>", "->", "-|-", "-", "+", "/", "=", "%", "?||",
+            "?|", "?-|", "?-", "?#", "?&", "?", "@@@", "@@", "@>", "@?", "@-@", "@", "^@", "^",
+            "|&>", "|>>", "|/", "|", "||/", "||", "~>=~", "~>~", "~<=~", "~<~", "~=", "~*", "~~*",
+            "~~", "~", "%", "<%", "%>", "<<%", "%>>", "<<->", "<->>", "<<<->", "<->>>",
+        ];
+
+        // Test each operator individually
+        for &operator in &operators {
+            let input = format!("left {} right", operator);
+            let expected = format!("left {} right", operator);
+            let options = FormatOptions {
+                uppercase: None,
+                ..FormatOptions::default()
+            };
+
+            assert_eq!(
+                format(&input, &QueryParams::None, &options),
+                expected,
+                "Failed to parse operator: {}",
+                operator
+            );
+        }
+    }
+    #[test]
+    fn it_correctly_splits_operators() {
+        let input = "
+  SELECT
+  left <@ right,
+  left << right,
+  left >> right,
+  left &< right,
+  left &> right,
+  left -|- right,
+  @@ left,
+  @-@ left,
+  left <-> right,
+  left <<| right,
+  left |>> right,
+  left &<| right,
+  left |>& right,
+  left <^ right,
+  left >^ right,
+  left <% right,
+  left %> right,
+  ?- left,
+  left ?-| right,
+  left ?|| right,
+  left ~= right";
+        let options = FormatOptions {
+            uppercase: None,
+            ..FormatOptions::default()
+        };
+        let expected = indoc!(
+            "
+SELECT
+  left <@ right,
+  left << right,
+  left >> right,
+  left &< right,
+  left &> right,
+  left -|- right,
+  @@ left,
+  @-@ left,
+  left <-> right,
+  left <<| right,
+  left |>> right,
+  left &<| right,
+  left |>& right,
+  left <^ right,
+  left >^ right,
+  left <% right,
+  left %> right,
+  ?- left,
+  left ?-| right,
+  left ?|| right,
+  left ~= right"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
+    }
+    #[test]
+    fn it_formats_double_colons() {
+        let input = "select text  ::  text, num::integer, data::json, (x - y)::integer  frOM foo";
+        let options = FormatOptions {
+            uppercase: Some(false),
+            ..FormatOptions::default()
+        };
+        let expected = indoc!(
+            "
+select
+  text::text,
+  num::integer,
+  data::json,
+  (x - y)::integer
+from
+  foo"
+        );
+
+        assert_eq!(format(input, &QueryParams::None, &options), expected);
     }
 }
