@@ -55,33 +55,42 @@
 //! ```
 //! # use anyhow::Result;
 //! # use vergen::Emitter;
-#![cfg_attr(feature = "build", doc = r"# use vergen::BuildBuilder;")]
-#![cfg_attr(feature = "cargo", doc = r"# use vergen::CargoBuilder;")]
-#![cfg_attr(feature = "rustc", doc = r"# use vergen::RustcBuilder;")]
-#![cfg_attr(feature = "si", doc = r"# use vergen::SysinfoBuilder;")]
-#![cfg_attr(feature = "cargo", doc = r"# use test_util::with_cargo_vars;")]
+#![cfg_attr(feature = "build", doc = r##"# use vergen::BuildBuilder;"##)]
+#![cfg_attr(feature = "cargo", doc = r##"# use vergen::CargoBuilder;"##)]
+#![cfg_attr(feature = "rustc", doc = r##"# use vergen::RustcBuilder;"##)]
+#![cfg_attr(feature = "si", doc = r##"# use vergen::SysinfoBuilder;"##)]
+#![cfg_attr(feature = "cargo", doc = r##"# use test_util::with_cargo_vars;"##)]
 //! #
 //! # pub fn main() -> Result<()> {
-#![cfg_attr(feature = "cargo", doc = r"# let result = with_cargo_vars(|| {")]
+#![cfg_attr(feature = "cargo", doc = r##"# let result = with_cargo_vars(|| {"##)]
 //! // NOTE: This will output everything, and requires all features enabled.
 //! // NOTE: See the specific builder documentation for configuration options.
-#![cfg_attr(feature = "build", doc = r"let build = BuildBuilder::all_build()?;")]
-#![cfg_attr(feature = "cargo", doc = r"let cargo = CargoBuilder::all_cargo()?;")]
-#![cfg_attr(feature = "rustc", doc = r"let rustc = RustcBuilder::all_rustc()?;")]
-#![cfg_attr(feature = "si", doc = r"let si = SysinfoBuilder::all_sysinfo()?;")]
+#![cfg_attr(
+    feature = "build",
+    doc = r##"let build = BuildBuilder::all_build()?;"##
+)]
+#![cfg_attr(
+    feature = "cargo",
+    doc = r##"let cargo = CargoBuilder::all_cargo()?;"##
+)]
+#![cfg_attr(
+    feature = "rustc",
+    doc = r##"let rustc = RustcBuilder::all_rustc()?;"##
+)]
+#![cfg_attr(feature = "si", doc = r##"let si = SysinfoBuilder::all_sysinfo()?;"##)]
 //!
 //! Emitter::default()
-#![cfg_attr(feature = "build", doc = r"    .add_instructions(&build)?")]
-#![cfg_attr(feature = "cargo", doc = r"    .add_instructions(&cargo)?")]
-#![cfg_attr(feature = "rustc", doc = r"    .add_instructions(&rustc)?")]
-#![cfg_attr(feature = "si", doc = r"    .add_instructions(&si)?")]
+#![cfg_attr(feature = "build", doc = r##"    .add_instructions(&build)?"##)]
+#![cfg_attr(feature = "cargo", doc = r##"    .add_instructions(&cargo)?"##)]
+#![cfg_attr(feature = "rustc", doc = r##"    .add_instructions(&rustc)?"##)]
+#![cfg_attr(feature = "si", doc = r##"    .add_instructions(&si)?"##)]
 //!     .emit()?;
 #![cfg_attr(
     feature = "cargo",
-    doc = r"
+    doc = r##"
 # Ok(())
 # });
-# assert!(result.is_ok());"
+# assert!(result.is_ok());"##
 )]
 //! #    Ok(())
 //! # }
@@ -120,45 +129,45 @@
 //! ```
 //! # use anyhow::Result;
 //! # use vergen::Emitter;
-#![cfg_attr(feature = "build", doc = r"# use vergen::BuildBuilder;")]
-#![cfg_attr(feature = "cargo", doc = r"# use vergen::CargoBuilder;")]
-#![cfg_attr(feature = "rustc", doc = r"# use vergen::RustcBuilder;")]
-#![cfg_attr(feature = "si", doc = r"# use vergen::SysinfoBuilder;")]
-#![cfg_attr(feature = "cargo", doc = r"# use test_util::with_cargo_vars;")]
+#![cfg_attr(feature = "build", doc = r##"# use vergen::BuildBuilder;"##)]
+#![cfg_attr(feature = "cargo", doc = r##"# use vergen::CargoBuilder;"##)]
+#![cfg_attr(feature = "rustc", doc = r##"# use vergen::RustcBuilder;"##)]
+#![cfg_attr(feature = "si", doc = r##"# use vergen::SysinfoBuilder;"##)]
+#![cfg_attr(feature = "cargo", doc = r##"# use test_util::with_cargo_vars;"##)]
 //! #
 //! # pub fn main() -> Result<()> {
-#![cfg_attr(feature = "cargo", doc = r"# let result = with_cargo_vars(|| {")]
+#![cfg_attr(feature = "cargo", doc = r##"# let result = with_cargo_vars(|| {"##)]
 #![cfg_attr(
     feature = "build",
-    doc = r"// NOTE: This will output only the instructions specified.
+    doc = r##"// NOTE: This will output only the instructions specified.
 // NOTE: See the specific builder documentation for configuration options. 
-let build = BuildBuilder::default().build_timestamp(true).build()?;"
+let build = BuildBuilder::default().build_timestamp(true).build()?;"##
 )]
 #![cfg_attr(
     feature = "cargo",
-    doc = r"let cargo = CargoBuilder::default().opt_level(true).build()?;"
+    doc = r##"let cargo = CargoBuilder::default().opt_level(true).build()?;"##
 )]
 #![cfg_attr(
     feature = "rustc",
-    doc = r"let rustc = RustcBuilder::default().semver(true).build()?;"
+    doc = r##"let rustc = RustcBuilder::default().semver(true).build()?;"##
 )]
 #![cfg_attr(
     feature = "si",
-    doc = r"let si = SysinfoBuilder::default().cpu_core_count(true).build()?;"
+    doc = r##"let si = SysinfoBuilder::default().cpu_core_count(true).build()?;"##
 )]
 //!
 //! Emitter::default()
-#![cfg_attr(feature = "build", doc = r"    .add_instructions(&build)?")]
-#![cfg_attr(feature = "cargo", doc = r"    .add_instructions(&cargo)?")]
-#![cfg_attr(feature = "rustc", doc = r"    .add_instructions(&rustc)?")]
-#![cfg_attr(feature = "si", doc = r"    .add_instructions(&si)?")]
+#![cfg_attr(feature = "build", doc = r##"    .add_instructions(&build)?"##)]
+#![cfg_attr(feature = "cargo", doc = r##"    .add_instructions(&cargo)?"##)]
+#![cfg_attr(feature = "rustc", doc = r##"    .add_instructions(&rustc)?"##)]
+#![cfg_attr(feature = "si", doc = r##"    .add_instructions(&si)?"##)]
 //!     .emit()?;
 #![cfg_attr(
     feature = "cargo",
-    doc = r"
+    doc = r##"
 #   Ok(())
 # });
-#    assert!(result.is_ok());"
+#    assert!(result.is_ok());"##
 )]
 //! #   Ok(())
 //! # }
@@ -190,7 +199,7 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
 //! You **must** specifically enable the features you wish to use.  
 #![cfg_attr(
     feature = "emit_and_set",
-    doc = r"There is also a toggle for the [`emit_and_set`](Emitter::emit_and_set) function.  This version of emit will also set the instructions you requests as environment variables for use in `build.rs`"
+    doc = r##"There is also a toggle for the [`emit_and_set`](Emitter::emit_and_set) function.  This version of emit will also set the instructions you requests as environment variables for use in `build.rs`"##
 )]
 //!
 //! |    Feature   | Enables                       |
@@ -201,7 +210,7 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
 //! |      si      | `VERGEN_SYSINFO_*` instructions |
 #![cfg_attr(
     feature = "emit_and_set",
-    doc = r"| emit_and_set | Enable the [`emit_and_set`](Emitter::emit_and_set) function |"
+    doc = r##"| emit_and_set | Enable the `[`emit_and_set`](Emitter::emit_and_set)` function |"##
 )]
 //!
 //! ## Environment Variables
@@ -292,7 +301,7 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
         must_not_suspend,
         non_exhaustive_omitted_patterns_lint,
         rustdoc_missing_doc_code_examples,
-        strict_provenance_lints,
+        strict_provenance,
     )
 )]
 #![cfg_attr(nightly, allow(single_use_lifetimes, unexpected_cfgs))]
@@ -310,12 +319,13 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
         bad_asm_style,
         bare_trait_objects,
         break_with_label_and_loop,
+        byte_slice_in_packed_struct_with_derive,
         clashing_extern_declarations,
         coherence_leak_check,
         confusable_idents,
+        const_eval_mutable_ptr_in_final_value,
         const_evaluatable_unchecked,
         const_item_mutation,
-        dangling_pointers_from_temporaries,
         dead_code,
         deprecated,
         deprecated_in_future,
@@ -394,6 +404,7 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
         stable_features,
         static_mut_refs,
         suspicious_double_ref_op,
+        temporary_cstring_as_ptr,
         trivial_bounds,
         trivial_casts,
         trivial_numeric_casts,
@@ -417,6 +428,7 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
         unsafe_op_in_unsafe_fn,
         unstable_name_collisions,
         unstable_syntax_pre_expansion,
+        unsupported_calling_conventions,
         unused_allocation,
         unused_assignments,
         unused_associated_type_bounds,
@@ -444,6 +456,7 @@ let build = BuildBuilder::default().build_timestamp(true).build()?;"
         variant_size_differences,
         wasm_c_abi,
         while_true,
+        writes_through_immutable_pointer,
     )
 )]
 #![cfg_attr(all(nightly), allow(unstable_features))]
