@@ -358,14 +358,15 @@ impl Lowerer {
                 let tid = self.tid.gen();
 
                 // pull columns from the table decl
-                let frame = expr.lineage.as_ref().unwrap();
-                let columns = (frame.columns.iter())
-                    .map(|c| {
-                        RelationColumn::Single(
-                            c.as_single().unwrap().0.as_ref().map(|i| i.name.clone()),
-                        )
+                let lineage = expr.lineage.as_ref().unwrap();
+                let columns: Vec<_> = (lineage.columns.iter())
+                    .map(|c| match c {
+                        LineageColumn::Single { name, .. } => Ok(RelationColumn::Single(
+                            name.as_ref().map(|i| i.name.clone()),
+                        )),
+                        LineageColumn::All { .. } => Err(Error::new_bug(4317)),
                     })
-                    .collect_vec();
+                    .try_collect()?;
 
                 let lit = RelationLiteral {
                     columns: columns
@@ -681,7 +682,7 @@ impl Lowerer {
 
     fn declare_as_columns(&mut self, exprs: pl::Expr, is_aggregation: bool) -> Result<Vec<CId>> {
         // special case: reference to a tuple that is a relational input
-        if exprs.ty.as_ref().map_or(false, |x| x.kind.is_tuple()) && exprs.kind.is_ident() {
+        if exprs.ty.as_ref().is_some_and(|x| x.kind.is_tuple()) && exprs.kind.is_ident() {
             // return all contained columns
             let input_id = exprs.target_id.as_ref().unwrap();
             let id_mapping = self.node_mapping.get(input_id).unwrap();
@@ -740,7 +741,7 @@ impl Lowerer {
 
             let id = e.target_id.unwrap();
             match e.kind {
-                pl::ExprKind::Ident(_) if e.ty.as_ref().map_or(false, |x| x.kind.is_tuple()) => {
+                pl::ExprKind::Ident(_) if e.ty.as_ref().is_some_and(|x| x.kind.is_tuple()) => {
                     res.extend(self.find_selected_all(e, None).with_span(except.span)?);
                 }
                 pl::ExprKind::Ident(ident) => {
@@ -834,7 +835,7 @@ impl Lowerer {
             pl::ExprKind::Ident(ident) => {
                 log::debug!("lowering ident {ident} (target {:?})", expr.target_id);
 
-                if expr.ty.as_ref().map_or(false, |x| x.kind.is_tuple()) {
+                if expr.ty.as_ref().is_some_and(|x| x.kind.is_tuple()) {
                     // special case: tuple ref
                     let expr = pl::Expr {
                         kind: pl::ExprKind::Ident(ident),
