@@ -251,7 +251,7 @@ impl Resolver<'_> {
 
                 let [pattern, value] = unpack::<2>(func.args);
 
-                if pattern.ty.as_ref().map_or(false, |x| x.kind.is_array()) {
+                if pattern.ty.as_ref().is_some_and(|x| x.kind.is_array()) {
                     return Ok(Expr::new(ExprKind::RqOperator {
                         name: "std.array_in".to_string(),
                         args: vec![value, pattern],
@@ -464,7 +464,8 @@ impl Resolver<'_> {
 
     /// Wraps non-tuple Exprs into a singleton Tuple.
     pub(super) fn coerce_into_tuple(&mut self, expr: Expr) -> Result<Expr> {
-        let is_tuple_ty = expr.ty.as_ref().unwrap().kind.is_tuple() && !expr.kind.is_all();
+        let is_tuple_ty =
+            expr.ty.as_ref().is_some_and(|t| t.kind.is_tuple()) && !expr.kind.is_all();
         Ok(if is_tuple_ty {
             // a helpful check for a common anti-pattern
             if let Some(alias) = expr.alias {
@@ -499,7 +500,7 @@ impl Resolver<'_> {
             TransformKind::Select { assigns } => assigns
                 .ty
                 .clone()
-                .map(|x| Ty::new(TyKind::Array(Box::new(x)))),
+                .map(|x| Ty::new(TyKind::Array(Some(Box::new(x))))),
             TransformKind::Derive { assigns } => {
                 let input = transform_call.input.ty.clone().unwrap();
                 let input = input.into_relation().unwrap();
@@ -507,14 +508,14 @@ impl Resolver<'_> {
                 let derived = assigns.ty.clone().unwrap();
                 let derived = derived.kind.into_tuple().unwrap();
 
-                Some(Ty::new(TyKind::Array(Box::new(Ty::new(ty_tuple_kind(
-                    [input, derived].concat(),
+                Some(Ty::new(TyKind::Array(Some(Box::new(Ty::new(
+                    ty_tuple_kind([input, derived].concat()),
                 ))))))
             }
             TransformKind::Aggregate { assigns } => {
                 let tuple = assigns.ty.clone().unwrap();
 
-                Some(Ty::new(TyKind::Array(Box::new(tuple))))
+                Some(Ty::new(TyKind::Array(Some(Box::new(tuple)))))
             }
             TransformKind::Filter { .. }
             | TransformKind::Sort { .. }
@@ -525,11 +526,11 @@ impl Resolver<'_> {
 
                 let with_name = with.alias.clone();
                 let with = with.ty.clone().unwrap();
-                let with = with.kind.into_array().unwrap();
+                let with = with.kind.into_array().unwrap().unwrap();
                 let with = TyTupleField::Single(with_name, Some(*with));
 
-                Some(Ty::new(TyKind::Array(Box::new(Ty::new(ty_tuple_kind(
-                    [input, vec![with]].concat(),
+                Some(Ty::new(TyKind::Array(Some(Box::new(Ty::new(
+                    ty_tuple_kind([input, vec![with]].concat()),
                 ))))))
             }
             TransformKind::Group { pipeline, by } => {
@@ -540,8 +541,8 @@ impl Resolver<'_> {
                 let pipeline = pipeline.kind.into_function().unwrap().unwrap();
                 let pipeline = pipeline.return_ty.unwrap().into_relation().unwrap();
 
-                Some(Ty::new(TyKind::Array(Box::new(Ty::new(ty_tuple_kind(
-                    [by, pipeline].concat(),
+                Some(Ty::new(TyKind::Array(Some(Box::new(Ty::new(
+                    ty_tuple_kind([by, pipeline].concat()),
                 ))))))
             }
             TransformKind::Window { pipeline, .. } | TransformKind::Loop(pipeline) => {
@@ -645,7 +646,6 @@ impl Resolver<'_> {
             named_params: vec![],
 
             env: Default::default(),
-            generic_type_params: Default::default(),
         });
         Ok(*expr_of_func(func, span))
     }
@@ -892,7 +892,7 @@ impl Lineage {
         }
 
         // special case: include a tuple
-        if expr.ty.as_ref().map_or(false, |x| x.kind.is_tuple()) && expr.kind.is_ident() {
+        if expr.ty.as_ref().is_some_and(|x| x.kind.is_tuple()) && expr.kind.is_ident() {
             // this ident is a tuple, which means it much point to an input
             let input_id = expr.target_id.unwrap();
 
