@@ -3,7 +3,6 @@ use super::*;
 use std::{
     collections::{hash_map::Entry, HashMap},
     fs,
-    mem::replace,
     path::{Path, PathBuf},
 };
 
@@ -95,6 +94,7 @@ pub struct Source<I: AsRef<str> = String> {
     lines: Vec<Line>,
     len: usize,
     byte_len: usize,
+    display_line_offset: usize,
 }
 
 impl<I: AsRef<str>> Source<I> {
@@ -109,51 +109,54 @@ impl<I: AsRef<str>> From<I> for Source<I> {
     ///
     /// Note that this function can be expensive for long strings. Use an implementor of [`Cache`] where possible.
     fn from(input: I) -> Self {
+        // `input.split_inclusive()` will not iterate at all,
+        // but an empty input still ought to count as a single empty line.
+        if input.as_ref().is_empty() {
+            return Self {
+                text: input,
+                lines: vec![Line {
+                    offset: 0,
+                    char_len: 0,
+                    byte_offset: 0,
+                    byte_len: 0,
+                }],
+                len: 0,
+                byte_len: 0,
+                display_line_offset: 0,
+            };
+        }
+
         let mut char_offset = 0;
         let mut byte_offset = 0;
-        // (Last line, last line ends with CR)
-        let mut last_line: Option<(Line, bool)> = None;
-        let mut lines: Vec<Line> = input
-            .as_ref()
-            .split_inclusive([
-                '\r',       // Carriage return
-                '\n',       // Line feed
-                '\x0B',     // Vertical tab
-                '\x0C',     // Form feed
-                '\u{0085}', // Next line
-                '\u{2028}', // Line separator
-                '\u{2029}', // Paragraph separator
-            ])
-            .flat_map(|line| {
-                // Returns last line and set `last_line` to current `line`
-                // A hack that makes `flat_map` deals with consecutive lines
+        let mut lines = Vec::new();
 
-                if let Some((last, ends_with_cr)) = last_line.as_mut() {
-                    if *ends_with_cr && line == "\n" {
-                        last.char_len += 1;
-                        last.byte_len += 1;
-                        char_offset += 1;
-                        byte_offset += 1;
-                        return last_line.take().map(|(l, _)| l);
-                    }
-                }
+        const SEPARATORS: [char; 7] = [
+            '\r',       // Carriage return
+            '\n',       // Line feed
+            '\x0B',     // Vertical tab
+            '\x0C',     // Form feed
+            '\u{0085}', // Next line
+            '\u{2028}', // Line separator
+            '\u{2029}', // Paragraph separator
+        ];
+        let mut remaining = input.as_ref().split_inclusive(SEPARATORS).peekable();
+        while let Some(line) = remaining.next() {
+            let mut byte_len = line.len();
+            let mut char_len = line.chars().count();
+            // Handle CRLF as a single terminator.
+            if line.ends_with('\r') && remaining.next_if_eq(&"\n").is_some() {
+                byte_len += 1;
+                char_len += 1;
+            }
+            lines.push(Line {
+                offset: char_offset,
+                char_len,
+                byte_offset,
+                byte_len,
+            });
 
-                let char_len = line.chars().count();
-                let ends_with_cr = line.ends_with('\r');
-                let line = Line {
-                    offset: char_offset,
-                    char_len,
-                    byte_offset,
-                    byte_len: line.len(),
-                };
-                char_offset += char_len;
-                byte_offset += line.byte_len;
-                replace(&mut last_line, Some((line, ends_with_cr))).map(|(l, _)| l)
-            })
-            .collect();
-
-        if let Some((l, _)) = last_line {
-            lines.push(l);
+            char_offset += char_len;
+            byte_offset += byte_len;
         }
 
         Self {
@@ -161,11 +164,23 @@ impl<I: AsRef<str>> From<I> for Source<I> {
             lines,
             len: char_offset,
             byte_len: byte_offset,
+            display_line_offset: 0,
         }
     }
 }
 
 impl<I: AsRef<str>> Source<I> {
+    /// Add an offset to the printed line numbers
+    pub fn with_display_line_offset(mut self, offset: usize) -> Self {
+        self.display_line_offset = offset;
+        self
+    }
+
+    /// Get the offset added to printed line numbers
+    pub fn display_line_offset(&self) -> usize {
+        self.display_line_offset
+    }
+
     /// Get the length of the total number of characters in the source.
     pub fn len(&self) -> usize {
         self.len
@@ -398,7 +413,7 @@ mod tests {
 
     #[test]
     fn source_from_empty() {
-        test_with_lines(vec![]); // Empty string
+        test_with_lines(vec![""]); // Empty string
     }
 
     #[test]
