@@ -134,7 +134,8 @@ fn test_take() {
         value:
           FuncCall:
             name:
-              Ident: take
+              Ident:
+                - take
               span: "0:0-4"
             args:
               - Literal:
@@ -151,7 +152,8 @@ fn test_take() {
         value:
           FuncCall:
             name:
-              Ident: take
+              Ident:
+                - take
               span: "0:0-4"
             args:
               - Range:
@@ -172,7 +174,8 @@ fn test_take() {
         value:
           FuncCall:
             name:
-              Ident: take
+              Ident:
+                - take
               span: "0:0-4"
             args:
               - Range:
@@ -200,12 +203,14 @@ fn test_filter() {
         value:
           FuncCall:
             name:
-              Ident: filter
+              Ident:
+                - filter
               span: "0:0-6"
             args:
               - Binary:
                   left:
-                    Ident: country
+                    Ident:
+                      - country
                     span: "0:7-14"
                   op: Eq
                   right:
@@ -225,22 +230,21 @@ fn test_filter() {
         value:
           FuncCall:
             name:
-              Ident: filter
+              Ident:
+                - filter
               span: "0:0-6"
             args:
               - Binary:
                   left:
                     FuncCall:
                       name:
-                        Indirection:
-                          base:
-                            Ident: text
-                            span: "0:8-12"
-                          field:
-                            Name: upper
-                        span: "0:12-18"
+                        Ident:
+                          - text
+                          - upper
+                        span: "0:8-18"
                       args:
-                        - Ident: country
+                        - Ident:
+                            - country
                           span: "0:19-26"
                     span: "0:8-26"
                   op: Eq
@@ -271,28 +275,34 @@ fn test_aggregate() {
         value:
           FuncCall:
             name:
-              Ident: group
+              Ident:
+                - group
               span: "0:0-5"
             args:
               - Tuple:
-                  - Ident: title
+                  - Ident:
+                      - title
                     span: "0:7-12"
                 span: "0:6-13"
               - FuncCall:
                   name:
-                    Ident: aggregate
+                    Ident:
+                      - aggregate
                     span: "0:32-41"
                   args:
                     - Tuple:
                         - FuncCall:
                             name:
-                              Ident: sum
+                              Ident:
+                                - sum
                               span: "0:43-46"
                             args:
-                              - Ident: salary
+                              - Ident:
+                                  - salary
                                 span: "0:47-53"
                           span: "0:43-53"
-                        - Ident: count
+                        - Ident:
+                            - count
                           span: "0:55-60"
                       span: "0:42-61"
                 span: "0:32-61"
@@ -313,25 +323,30 @@ fn test_aggregate() {
         value:
           FuncCall:
             name:
-              Ident: group
+              Ident:
+                - group
               span: "0:0-5"
             args:
               - Tuple:
-                  - Ident: title
+                  - Ident:
+                      - title
                     span: "0:7-12"
                 span: "0:6-13"
               - FuncCall:
                   name:
-                    Ident: aggregate
+                    Ident:
+                      - aggregate
                     span: "0:32-41"
                   args:
                     - Tuple:
                         - FuncCall:
                             name:
-                              Ident: sum
+                              Ident:
+                                - sum
                               span: "0:43-46"
                             args:
-                              - Ident: salary
+                              - Ident:
+                                  - salary
                                 span: "0:47-53"
                           span: "0:43-53"
                       span: "0:42-54"
@@ -354,10 +369,12 @@ fn test_basic_exprs() {
         value:
           FuncCall:
             name:
-              Ident: select
+              Ident:
+                - select
               span: "0:28-34"
             args:
-              - Ident: a
+              - Ident:
+                  - a
                 span: "0:35-36"
           span: "0:28-36"
       span: "0:0-36"
@@ -376,7 +393,8 @@ fn test_function() {
             body:
               Binary:
                 left:
-                  Ident: x
+                  Ident:
+                    - x
                   span: "0:21-22"
                 op: Add
                 right:
@@ -388,7 +406,6 @@ fn test_function() {
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:15-26"
       span: "0:0-26"
     "#);
@@ -401,13 +418,13 @@ fn test_function() {
           Func:
             return_ty: ~
             body:
-              Ident: x
+              Ident:
+                - x
               span: "0:21-22"
             params:
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:15-22"
       span: "0:0-22"
     "#);
@@ -422,7 +439,8 @@ fn test_function() {
             body:
               Binary:
                 left:
-                  Ident: x
+                  Ident:
+                    - x
                   span: "0:22-23"
                 op: Add
                 right:
@@ -434,7 +452,6 @@ fn test_function() {
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:15-28"
       span: "0:0-28"
     "#);
@@ -449,7 +466,8 @@ fn test_function() {
             body:
               Binary:
                 left:
-                  Ident: x
+                  Ident:
+                    - x
                   span: "0:21-22"
                 op: Add
                 right:
@@ -461,7 +479,6 @@ fn test_function() {
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:15-26"
       span: "0:0-26"
     "#);
@@ -477,17 +494,20 @@ fn test_function() {
             body:
               FuncCall:
                 name:
-                  Ident: some_func
+                  Ident:
+                    - some_func
                   span: "0:15-24"
                 args:
                   - FuncCall:
                       name:
-                        Ident: foo
+                        Ident:
+                          - foo
                         span: "0:26-29"
                       args:
                         - Binary:
                             left:
-                              Ident: bar
+                              Ident:
+                                - bar
                               span: "0:30-33"
                             op: Add
                             right:
@@ -498,11 +518,13 @@ fn test_function() {
                     span: "0:26-37"
                   - Binary:
                       left:
-                        Ident: plax
+                        Ident:
+                          - plax
                         span: "0:40-44"
                       op: Sub
                       right:
-                        Ident: baz
+                        Ident:
+                          - baz
                         span: "0:48-51"
                     span: "0:39-51"
               span: "0:15-51"
@@ -510,7 +532,6 @@ fn test_function() {
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:10-51"
       span: "0:0-51"
     "#);
@@ -530,7 +551,6 @@ fn test_function() {
               - name: return_constant
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:0-27"
       span: "0:0-27"
     "#);
@@ -548,7 +568,8 @@ fn test_function() {
                 - String: SUM(
                 - Expr:
                     expr:
-                      Ident: X
+                      Ident:
+                        - X
                       span: "0:24-25"
                     format: ~
                 - String: )
@@ -557,7 +578,6 @@ fn test_function() {
               - name: X
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:12-28"
       span: "0:0-28"
     "#);
@@ -584,31 +604,38 @@ fn test_function() {
                 exprs:
                   - FuncCall:
                       name:
-                        Ident: window
+                        Ident:
+                          - window
                         span: "0:51-57"
                       args:
-                        - Ident: x
+                        - Ident:
+                            - x
                           span: "0:58-59"
                     span: "0:51-59"
                   - FuncCall:
                       name:
-                        Ident: by
+                        Ident:
+                          - by
                         span: "0:76-78"
                       args:
-                        - Ident: sec_id
+                        - Ident:
+                            - sec_id
                           span: "0:79-85"
                     span: "0:76-85"
                   - FuncCall:
                       name:
-                        Ident: sort
+                        Ident:
+                          - sort
                         span: "0:102-106"
                       args:
-                        - Ident: date
+                        - Ident:
+                            - date
                           span: "0:107-111"
                     span: "0:102-111"
                   - FuncCall:
                       name:
-                        Ident: lag
+                        Ident:
+                          - lag
                         span: "0:128-131"
                       args:
                         - Literal:
@@ -620,7 +647,6 @@ fn test_function() {
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:27-147"
       span: "0:0-147"
     "#);
@@ -635,11 +661,13 @@ fn test_function() {
             body:
               Binary:
                 left:
-                  Ident: x
+                  Ident:
+                    - x
                   span: "0:21-22"
                 op: Add
                 right:
-                  Ident: to
+                  Ident:
+                    - to
                   span: "0:25-27"
               span: "0:21-27"
             params:
@@ -648,9 +676,9 @@ fn test_function() {
             named_params:
               - name: to
                 default_value:
-                  Ident: a
+                  Ident:
+                    - a
                   span: "0:15-16"
-            generic_type_params: []
           span: "0:10-27"
       span: "0:0-27"
     "#);
@@ -667,10 +695,12 @@ fn test_var_def() {
         value:
           FuncCall:
             name:
-              Ident: from
+              Ident:
+                - from
               span: "0:24-28"
             args:
-              - Ident: employees
+              - Ident:
+                  - employees
                 span: "0:29-38"
           span: "0:23-39"
       span: "0:0-39"
@@ -697,31 +727,38 @@ fn test_var_def() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:35-39"
                   args:
-                    - Ident: employees
+                    - Ident:
+                        - employees
                       span: "0:40-49"
                 span: "0:35-49"
               - FuncCall:
                   name:
-                    Ident: group
+                    Ident:
+                      - group
                     span: "0:60-65"
                   args:
-                    - Ident: country
+                    - Ident:
+                        - country
                       span: "0:66-73"
                     - FuncCall:
                         name:
-                          Ident: aggregate
+                          Ident:
+                            - aggregate
                           span: "0:88-97"
                         args:
                           - Tuple:
                               - FuncCall:
                                   name:
-                                    Ident: average
+                                    Ident:
+                                      - average
                                     span: "0:141-148"
                                   args:
-                                    - Ident: salary
+                                    - Ident:
+                                        - salary
                                       span: "0:149-155"
                                 span: "0:141-155"
                                 alias: average_country_salary
@@ -730,15 +767,18 @@ fn test_var_def() {
                 span: "0:60-181"
               - FuncCall:
                   name:
-                    Ident: sort
+                    Ident:
+                      - sort
                     span: "0:192-196"
                   args:
-                    - Ident: tenure
+                    - Ident:
+                        - tenure
                       span: "0:197-203"
                 span: "0:192-203"
               - FuncCall:
                   name:
-                    Ident: take
+                    Ident:
+                      - take
                     span: "0:214-218"
                   args:
                     - Literal:
@@ -781,18 +821,22 @@ fn test_var_def() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:23-27"
                   args:
-                    - Ident: x_table
+                    - Ident:
+                        - x_table
                       span: "0:28-35"
                 span: "0:23-35"
               - FuncCall:
                   name:
-                    Ident: select
+                    Ident:
+                      - select
                     span: "0:49-55"
                   args:
-                    - Ident: foo
+                    - Ident:
+                        - foo
                       span: "0:68-71"
                       alias: only_in_x
                 span: "0:49-71"
@@ -804,10 +848,12 @@ fn test_var_def() {
         value:
           FuncCall:
             name:
-              Ident: from
+              Ident:
+                - from
               span: "0:96-100"
             args:
-              - Ident: x
+              - Ident:
+                  - x
                 span: "0:101-102"
           span: "0:96-102"
       span: "0:84-102"
@@ -826,11 +872,13 @@ fn test_inline_pipeline() {
             body:
               Pipeline:
                 exprs:
-                  - Ident: x
+                  - Ident:
+                      - x
                     span: "0:19-20"
                   - FuncCall:
                       name:
-                        Ident: percentile
+                        Ident:
+                          - percentile
                         span: "0:23-33"
                       args:
                         - Literal:
@@ -842,7 +890,6 @@ fn test_inline_pipeline() {
               - name: x
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:13-37"
       span: "0:0-37"
     "#);
@@ -865,21 +912,25 @@ fn test_sql_parameters() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:9-13"
                   args:
-                    - Ident: mytable
+                    - Ident:
+                        - mytable
                       span: "0:14-21"
                 span: "0:9-21"
               - FuncCall:
                   name:
-                    Ident: filter
+                    Ident:
+                      - filter
                     span: "0:30-36"
                   args:
                     - Tuple:
                         - Binary:
                             left:
-                              Ident: first_name
+                              Ident:
+                                - first_name
                               span: "0:49-59"
                             op: Eq
                             right:
@@ -888,7 +939,8 @@ fn test_sql_parameters() {
                           span: "0:49-65"
                         - Binary:
                             left:
-                              Ident: last_name
+                              Ident:
+                                - last_name
                               span: "0:77-86"
                             op: Eq
                             right:
@@ -935,67 +987,71 @@ join `my-proj`.`dataset`.`table`
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:1-5"
                   args:
-                    - Ident: a/*.parquet
+                    - Ident:
+                        - a/*.parquet
                       span: "0:6-19"
                 span: "0:1-19"
               - FuncCall:
                   name:
-                    Ident: aggregate
+                    Ident:
+                      - aggregate
                     span: "0:20-29"
                   args:
                     - Tuple:
                         - FuncCall:
                             name:
-                              Ident: max
+                              Ident:
+                                - max
                               span: "0:31-34"
                             args:
-                              - Ident: c
+                              - Ident:
+                                  - c
                                 span: "0:35-36"
                           span: "0:31-36"
                       span: "0:30-37"
                 span: "0:20-37"
               - FuncCall:
                   name:
-                    Ident: join
+                    Ident:
+                      - join
                     span: "0:38-42"
                   args:
-                    - Ident: schema.table
+                    - Ident:
+                        - schema.table
                       span: "0:43-57"
                     - Unary:
                         op: EqSelf
                         expr:
-                          Ident: id
+                          Ident:
+                            - id
                           span: "0:61-63"
                       span: "0:59-63"
                 span: "0:38-64"
               - FuncCall:
                   name:
-                    Ident: join
+                    Ident:
+                      - join
                     span: "0:65-69"
                   args:
-                    - Ident: my-proj.dataset.table
+                    - Ident:
+                        - my-proj.dataset.table
                       span: "0:70-93"
                 span: "0:65-93"
               - FuncCall:
                   name:
-                    Ident: join
+                    Ident:
+                      - join
                     span: "0:94-98"
                   args:
-                    - Indirection:
-                        base:
-                          Indirection:
-                            base:
-                              Ident: my-proj
-                              span: "0:99-108"
-                            field:
-                              Name: dataset
-                          span: "0:108-118"
-                        field:
-                          Name: table
-                      span: "0:118-126"
+                    - Ident:
+                        - my-proj
+                        - dataset
+                        - table
+                      span: "0:99-126"
                 span: "0:94-126"
           span: "0:1-126"
       span: "0:0-126"
@@ -1020,74 +1076,88 @@ fn test_sort() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:9-13"
                   args:
-                    - Ident: invoices
+                    - Ident:
+                        - invoices
                       span: "0:14-22"
                 span: "0:9-22"
               - FuncCall:
                   name:
-                    Ident: sort
+                    Ident:
+                      - sort
                     span: "0:31-35"
                   args:
-                    - Ident: issued_at
+                    - Ident:
+                        - issued_at
                       span: "0:36-45"
                 span: "0:31-45"
               - FuncCall:
                   name:
-                    Ident: sort
+                    Ident:
+                      - sort
                     span: "0:54-58"
                   args:
                     - Unary:
                         op: Neg
                         expr:
-                          Ident: issued_at
+                          Ident:
+                            - issued_at
                           span: "0:61-70"
                       span: "0:60-70"
                 span: "0:54-71"
               - FuncCall:
                   name:
-                    Ident: sort
+                    Ident:
+                      - sort
                     span: "0:80-84"
                   args:
                     - Tuple:
-                        - Ident: issued_at
+                        - Ident:
+                            - issued_at
                           span: "0:86-95"
                       span: "0:85-96"
                 span: "0:80-96"
               - FuncCall:
                   name:
-                    Ident: sort
+                    Ident:
+                      - sort
                     span: "0:105-109"
                   args:
                     - Tuple:
                         - Unary:
                             op: Neg
                             expr:
-                              Ident: issued_at
+                              Ident:
+                                - issued_at
                               span: "0:112-121"
                           span: "0:111-121"
                       span: "0:110-122"
                 span: "0:105-122"
               - FuncCall:
                   name:
-                    Ident: sort
+                    Ident:
+                      - sort
                     span: "0:131-135"
                   args:
                     - Tuple:
-                        - Ident: issued_at
+                        - Ident:
+                            - issued_at
                           span: "0:137-146"
                         - Unary:
                             op: Neg
                             expr:
-                              Ident: amount
+                              Ident:
+                                - amount
                               span: "0:149-155"
                           span: "0:148-155"
                         - Unary:
                             op: Add
                             expr:
-                              Ident: num_of_articles
+                              Ident:
+                                - num_of_articles
                               span: "0:158-173"
                           span: "0:157-173"
                       span: "0:136-174"
@@ -1111,21 +1181,25 @@ fn test_dates() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:9-13"
                   args:
-                    - Ident: employees
+                    - Ident:
+                        - employees
                       span: "0:14-23"
                 span: "0:9-23"
               - FuncCall:
                   name:
-                    Ident: derive
+                    Ident:
+                      - derive
                     span: "0:32-38"
                   args:
                     - Tuple:
                         - Binary:
                             left:
-                              Ident: age
+                              Ident:
+                                - age
                               span: "0:62-65"
                             op: Add
                             right:
@@ -1154,7 +1228,8 @@ fn test_multiline_string() {
         value:
           FuncCall:
             name:
-              Ident: derive
+              Ident:
+                - derive
               span: "0:9-15"
             args:
               - Literal:
@@ -1185,15 +1260,18 @@ derive x = 5
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:1-5"
                   args:
-                    - Ident: artists
+                    - Ident:
+                        - artists
                       span: "0:6-13"
                 span: "0:1-13"
               - FuncCall:
                   name:
-                    Ident: derive
+                    Ident:
+                      - derive
                     span: "0:14-20"
                   args:
                     - Literal:
@@ -1220,20 +1298,24 @@ fn test_coalesce() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:9-13"
                   args:
-                    - Ident: employees
+                    - Ident:
+                        - employees
                       span: "0:14-23"
                 span: "0:9-23"
               - FuncCall:
                   name:
-                    Ident: derive
+                    Ident:
+                      - derive
                     span: "0:32-38"
                   args:
                     - Binary:
                         left:
-                          Ident: amount
+                          Ident:
+                            - amount
                           span: "0:48-54"
                         op: Coalesce
                         right:
@@ -1259,7 +1341,8 @@ fn test_literal() {
         value:
           FuncCall:
             name:
-              Ident: derive
+              Ident:
+                - derive
               span: "0:9-15"
             args:
               - Literal:
@@ -1287,34 +1370,41 @@ fn test_allowed_idents() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:9-13"
                   args:
-                    - Ident: employees
+                    - Ident:
+                        - employees
                       span: "0:14-23"
                 span: "0:9-23"
               - FuncCall:
                   name:
-                    Ident: join
+                    Ident:
+                      - join
                     span: "0:32-36"
                   args:
-                    - Ident: _salary
+                    - Ident:
+                        - _salary
                       span: "0:37-44"
                     - Unary:
                         op: EqSelf
                         expr:
-                          Ident: employee_id
+                          Ident:
+                            - employee_id
                           span: "0:48-59"
                       span: "0:46-59"
                 span: "0:32-60"
               - FuncCall:
                   name:
-                    Ident: filter
+                    Ident:
+                      - filter
                     span: "0:101-107"
                   args:
                     - Binary:
                         left:
-                          Ident: first_name
+                          Ident:
+                            - first_name
                           span: "0:108-118"
                         op: Eq
                         right:
@@ -1324,16 +1414,14 @@ fn test_allowed_idents() {
                 span: "0:101-124"
               - FuncCall:
                   name:
-                    Ident: select
+                    Ident:
+                      - select
                     span: "0:133-139"
                   args:
                     - Tuple:
-                        - Indirection:
-                            base:
-                              Ident: _employees
-                              span: "0:141-151"
-                            field:
-                              Name: _underscored_column
+                        - Ident:
+                            - _employees
+                            - _underscored_column
                           span: "0:141-171"
                       span: "0:140-172"
                 span: "0:133-172"
@@ -1359,20 +1447,24 @@ fn test_gt_lt_gte_lte() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:9-13"
                   args:
-                    - Ident: people
+                    - Ident:
+                        - people
                       span: "0:14-20"
                 span: "0:9-20"
               - FuncCall:
                   name:
-                    Ident: filter
+                    Ident:
+                      - filter
                     span: "0:29-35"
                   args:
                     - Binary:
                         left:
-                          Ident: age
+                          Ident:
+                            - age
                           span: "0:36-39"
                         op: Gte
                         right:
@@ -1383,12 +1475,14 @@ fn test_gt_lt_gte_lte() {
                 span: "0:29-46"
               - FuncCall:
                   name:
-                    Ident: filter
+                    Ident:
+                      - filter
                     span: "0:55-61"
                   args:
                     - Binary:
                         left:
-                          Ident: num_grandchildren
+                          Ident:
+                            - num_grandchildren
                           span: "0:62-79"
                         op: Lte
                         right:
@@ -1399,12 +1493,14 @@ fn test_gt_lt_gte_lte() {
                 span: "0:55-85"
               - FuncCall:
                   name:
-                    Ident: filter
+                    Ident:
+                      - filter
                     span: "0:94-100"
                   args:
                     - Binary:
                         left:
-                          Ident: salary
+                          Ident:
+                            - salary
                           span: "0:101-107"
                         op: Gt
                         right:
@@ -1415,12 +1511,14 @@ fn test_gt_lt_gte_lte() {
                 span: "0:94-111"
               - FuncCall:
                   name:
-                    Ident: filter
+                    Ident:
+                      - filter
                     span: "0:120-126"
                   args:
                     - Binary:
                         left:
-                          Ident: num_eyes
+                          Ident:
+                            - num_eyes
                           span: "0:127-135"
                         op: Lt
                         right:
@@ -1448,24 +1546,29 @@ join s=salaries (==id)
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:1-5"
                   args:
-                    - Ident: employees
+                    - Ident:
+                        - employees
                       span: "0:6-15"
                 span: "0:1-15"
               - FuncCall:
                   name:
-                    Ident: join
+                    Ident:
+                      - join
                     span: "0:16-20"
                   args:
-                    - Ident: salaries
+                    - Ident:
+                        - salaries
                       span: "0:23-31"
                       alias: s
                     - Unary:
                         op: EqSelf
                         expr:
-                          Ident: id
+                          Ident:
+                            - id
                           span: "0:35-37"
                       span: "0:33-37"
                 span: "0:16-38"
@@ -1484,10 +1587,12 @@ fn test_unicode() {
         value:
           FuncCall:
             name:
-              Ident: from
+              Ident:
+                - from
               span: "0:0-4"
             args:
-              - Ident: tète
+              - Ident:
+                  - tète
                 span: "0:5-9"
           span: "0:0-9"
       span: "0:0-9"
@@ -1505,7 +1610,8 @@ fn test_var_defs() {
         kind: Let
         name: a
         value:
-          Ident: x
+          Ident:
+            - x
           span: "0:17-42"
       span: "0:0-42"
     "#);
@@ -1518,7 +1624,8 @@ fn test_var_defs() {
         kind: Into
         name: a
         value:
-          Ident: x
+          Ident:
+            - x
           span: "0:9-10"
       span: "0:0-25"
     "#);
@@ -1530,7 +1637,8 @@ fn test_var_defs() {
         kind: Main
         name: main
         value:
-          Ident: x
+          Ident:
+            - x
           span: "0:9-10"
       span: "0:0-10"
     "#);
@@ -1586,11 +1694,13 @@ fn test_annotation() {
             body:
               Binary:
                 left:
-                  Ident: a
+                  Ident:
+                    - a
                   span: "0:56-57"
                 op: Add
                 right:
-                  Ident: b
+                  Ident:
+                    - b
                   span: "0:60-61"
               span: "0:56-61"
             params:
@@ -1599,7 +1709,6 @@ fn test_annotation() {
               - name: b
                 default_value: ~
             named_params: []
-            generic_type_params: []
           span: "0:49-61"
       span: "0:0-61"
       annotations:
@@ -1710,18 +1819,22 @@ fn test_target() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:45-49"
                   args:
-                    - Ident: film
+                    - Ident:
+                        - film
                       span: "0:50-54"
                 span: "0:45-54"
               - FuncCall:
                   name:
-                    Ident: remove
+                    Ident:
+                      - remove
                     span: "0:65-71"
                   args:
-                    - Ident: film2
+                    - Ident:
+                        - film2
                       span: "0:72-77"
                 span: "0:65-77"
           span: "0:45-77"
@@ -1756,15 +1869,18 @@ fn doc_comment() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:5-9"
                   args:
-                    - Ident: artists
+                    - Ident:
+                        - artists
                       span: "0:10-17"
                 span: "0:5-17"
               - FuncCall:
                   name:
-                    Ident: derive
+                    Ident:
+                      - derive
                     span: "0:22-28"
                   args:
                     - Literal:
@@ -1789,10 +1905,12 @@ fn doc_comment() {
         value:
           FuncCall:
             name:
-              Ident: from
+              Ident:
+                - from
               span: "0:5-9"
             args:
-              - Ident: artists
+              - Ident:
+                  - artists
                 span: "0:10-17"
           span: "0:5-17"
       span: "0:0-17"
@@ -1802,7 +1920,8 @@ fn doc_comment() {
         value:
           FuncCall:
             name:
-              Ident: derive
+              Ident:
+                - derive
               span: "0:53-59"
             args:
               - Literal:
@@ -1827,15 +1946,18 @@ fn doc_comment() {
             exprs:
               - FuncCall:
                   name:
-                    Ident: from
+                    Ident:
+                      - from
                     span: "0:34-38"
                   args:
-                    - Ident: artists
+                    - Ident:
+                        - artists
                       span: "0:39-46"
                 span: "0:34-46"
               - FuncCall:
                   name:
-                    Ident: derive
+                    Ident:
+                      - derive
                     span: "0:51-57"
                   args:
                     - Literal:
