@@ -242,8 +242,8 @@ impl<S: Span> Report<'_, S> {
             let line_range = src.get_line_range(&char_span);
 
             // File name & reference
-            let location = if src_id == self.location.0.borrow() {
-                self.location.1
+            let location = if src_id == self.span.source() {
+                self.span.start()
             } else {
                 labels[0].char_span.start
             };
@@ -258,7 +258,12 @@ impl<S: Span> Report<'_, S> {
                 }),
             };
             let (line_no, col_no) = line_and_col
-                .map(|(_, idx, col)| (format!("{}", idx + 1), format!("{}", col + 1)))
+                .map(|(_, idx, col)| {
+                    (
+                        format!("{}", idx + 1 + src.display_line_offset()),
+                        format!("{}", col + 1),
+                    )
+                })
                 .unwrap_or_else(|| ('?'.to_string(), '?'.to_string()));
             let line_ref = format!(":{}:{}", line_no, col_no);
             writeln!(
@@ -863,13 +868,37 @@ impl<S: Span> Report<'_, S> {
             }
 
             // Note
-            if let (Some(note), true) = (&self.note, is_final_group) {
-                if !self.config.compact {
-                    write_margin(&mut w, 0, false, false, true, Some((0, false)), &[], &None)?;
-                    writeln!(w)?;
+            if is_final_group {
+                for (i, note) in self.notes.iter().enumerate() {
+                    if !self.config.compact {
+                        write_margin(&mut w, 0, false, false, true, Some((0, false)), &[], &None)?;
+                        writeln!(w)?;
+                    }
+                    let note_prefix = format!("{} {}", "Note", i + 1);
+                    let note_prefix_len = if self.notes.len() > 1 {
+                        note_prefix.len()
+                    } else {
+                        4
+                    };
+                    let mut lines = note.lines();
+                    if let Some(line) = lines.next() {
+                        write_margin(&mut w, 0, false, false, true, Some((0, false)), &[], &None)?;
+                        if self.notes.len() > 1 {
+                            writeln!(
+                                w,
+                                "{}: {}",
+                                note_prefix.fg(self.config.note_color(), s),
+                                line
+                            )?;
+                        } else {
+                            writeln!(w, "{}: {}", "Note".fg(self.config.note_color(), s), line)?;
+                        }
+                    }
+                    for line in lines {
+                        write_margin(&mut w, 0, false, false, true, Some((0, false)), &[], &None)?;
+                        writeln!(w, "{:>pad$}{}", "", line, pad = note_prefix_len + 2)?;
+                    }
                 }
-                write_margin(&mut w, 0, false, false, true, Some((0, false)), &[], &None)?;
-                writeln!(w, "{}: {}", "Note".fg(self.config.note_color(), s), note)?;
             }
 
             // Tail of report
@@ -927,7 +956,7 @@ mod tests {
 
     #[test]
     fn one_message() {
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .finish()
@@ -940,7 +969,7 @@ mod tests {
     #[test]
     fn two_labels_without_messages() {
         let source = "apple == orange;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(Label::new(0..5))
@@ -960,7 +989,7 @@ mod tests {
     #[test]
     fn two_labels_with_messages() {
         let source = "apple == orange;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(Label::new(0..5).with_message("This is an apple"))
@@ -984,7 +1013,7 @@ mod tests {
     #[test]
     fn multi_byte_chars() {
         let source = "äpplë == örängë;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii().with_index_type(IndexType::Char))
             .with_message("can't compare äpplës with örängës")
             .with_label(Label::new(0..5).with_message("This is an äpplë"))
@@ -1008,7 +1037,7 @@ mod tests {
     #[test]
     fn byte_label() {
         let source = "äpplë == örängë;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii().with_index_type(IndexType::Byte))
             .with_message("can't compare äpplës with örängës")
             .with_label(Label::new(0..7).with_message("This is an äpplë"))
@@ -1032,7 +1061,7 @@ mod tests {
     #[test]
     fn byte_column() {
         let source = "äpplë == örängë;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 11)
+        let msg = Report::build(ReportKind::Error, 11..11)
             .with_config(no_color_and_ascii().with_index_type(IndexType::Byte))
             .with_message("can't compare äpplës with örängës")
             .with_label(Label::new(0..7).with_message("This is an äpplë"))
@@ -1056,7 +1085,7 @@ mod tests {
     #[test]
     fn label_at_end_of_long_line() {
         let source = format!("{}orange", "apple == ".repeat(100));
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(
@@ -1079,7 +1108,7 @@ mod tests {
     #[test]
     fn label_of_width_zero_at_end_of_line() {
         let source = "apple ==\n";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii().with_index_type(IndexType::Byte))
             .with_message("unexpected end of file")
             .with_label(Label::new(9..9).with_message("Unexpected end of file"))
@@ -1097,13 +1126,109 @@ mod tests {
         "###);
     }
 
+    #[test]
+    fn empty_input() {
+        let source = "";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("unexpected end of file")
+            .with_label(Label::new(0..0).with_message("No more fruit!"))
+            .finish()
+            .write_to_string(Source::from(source));
+
+        assert_snapshot!(msg, @r###"
+        Error: unexpected end of file
+           ,-[<unknown>:1:1]
+           |
+         1 | 
+           | | 
+           | `- No more fruit!
+        ---'
+        "###);
+    }
+
+    #[test]
+    fn empty_input_help() {
+        let source = "";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("unexpected end of file")
+            .with_label(Label::new(0..0).with_message("No more fruit!"))
+            .with_help("have you tried going to the farmer's market?")
+            .finish()
+            .write_to_string(Source::from(source));
+
+        assert_snapshot!(msg, @r###"
+        Error: unexpected end of file
+           ,-[<unknown>:1:1]
+           |
+         1 | 
+           | | 
+           | `- No more fruit!
+           | 
+           | Help: have you tried going to the farmer's market?
+        ---'
+        "###);
+    }
+
+    #[test]
+    fn empty_input_note() {
+        let source = "";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("unexpected end of file")
+            .with_label(Label::new(0..0).with_message("No more fruit!"))
+            .with_note("eat your greens!")
+            .finish()
+            .write_to_string(Source::from(source));
+
+        assert_snapshot!(msg, @r###"
+        Error: unexpected end of file
+           ,-[<unknown>:1:1]
+           |
+         1 | 
+           | | 
+           | `- No more fruit!
+           | 
+           | Note: eat your greens!
+        ---'
+        "###);
+    }
+
+    #[test]
+    fn empty_input_help_note() {
+        let source = "";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("unexpected end of file")
+            .with_label(Label::new(0..0).with_message("No more fruit!"))
+            .with_note("eat your greens!")
+            .with_help("have you tried going to the farmer's market?")
+            .finish()
+            .write_to_string(Source::from(source));
+
+        assert_snapshot!(msg, @r###"
+        Error: unexpected end of file
+           ,-[<unknown>:1:1]
+           |
+         1 | 
+           | | 
+           | `- No more fruit!
+           | 
+           | Help: have you tried going to the farmer's market?
+           | 
+           | Note: eat your greens!
+        ---'
+        "###);
+    }
+
     #[test]
     fn byte_spans_never_crash() {
         let source = "apple\np\n\nempty\n";
 
         for i in 0..=source.len() {
             for j in i..=source.len() {
-                let _ = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+                let _ = Report::build(ReportKind::Error, 0..0)
                     .with_config(no_color_and_ascii().with_index_type(IndexType::Byte))
                     .with_message("Label")
                     .with_label(Label::new(i..j).with_message("Label"))
@@ -1116,7 +1241,7 @@ mod tests {
     #[test]
     fn multiline_label() {
         let source = "apple\n==\norange";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_label(Label::new(0..source.len()).with_message("illegal comparison"))
             .finish()
@@ -1138,7 +1263,7 @@ mod tests {
     #[test]
     fn partially_overlapping_labels() {
         let source = "https://example.com/";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_label(Label::new(0..source.len()).with_message("URL"))
             .with_label(Label::new(0..source.find(':').unwrap()).with_message("scheme"))
@@ -1161,7 +1286,7 @@ mod tests {
     #[test]
     fn multiple_labels_same_span() {
         let source = "apple == orange;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(Label::new(0..5).with_message("This is an apple"))
@@ -1196,7 +1321,7 @@ mod tests {
     #[test]
     fn note() {
         let source = "apple == orange;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(Label::new(0..5).with_message("This is an apple"))
@@ -1222,7 +1347,7 @@ mod tests {
     #[test]
     fn help() {
         let source = "apple == orange;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(Label::new(0..5).with_message("This is an apple"))
@@ -1248,7 +1373,7 @@ mod tests {
     #[test]
     fn help_and_note() {
         let source = "apple == orange;";
-        let msg = Report::<Range<usize>>::build(ReportKind::Error, (), 0)
+        let msg = Report::build(ReportKind::Error, 0..0)
             .with_config(no_color_and_ascii())
             .with_message("can't compare apples with oranges")
             .with_label(Label::new(0..5).with_message("This is an apple"))
@@ -1273,4 +1398,80 @@ mod tests {
         ---'
         "###)
     }
+
+    #[test]
+    fn single_note_single_line() {
+        let source = "apple == orange;";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("can't compare apples with oranges")
+            .with_label(Label::new(0..15).with_message("This is a strange comparison"))
+            .with_note("No need to try, they can't be compared.")
+            .finish()
+            .write_to_string(Source::from(source));
+        assert_snapshot!(msg, @r###"
+        Error: can't compare apples with oranges
+           ,-[<unknown>:1:1]
+           |
+         1 | apple == orange;
+           | ^^^^^^^|^^^^^^^  
+           |        `--------- This is a strange comparison
+           | 
+           | Note: No need to try, they can't be compared.
+        ---'
+        "###)
+    }
+
+    #[test]
+    fn multi_notes_single_lines() {
+        let source = "apple == orange;";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("can't compare apples with oranges")
+            .with_label(Label::new(0..15).with_message("This is a strange comparison"))
+            .with_note("No need to try, they can't be compared.")
+            .with_note("Yeah, really, please stop.")
+            .finish()
+            .write_to_string(Source::from(source));
+        assert_snapshot!(msg, @r###"
+        Error: can't compare apples with oranges
+           ,-[<unknown>:1:1]
+           |
+         1 | apple == orange;
+           | ^^^^^^^|^^^^^^^  
+           |        `--------- This is a strange comparison
+           | 
+           | Note 1: No need to try, they can't be compared.
+           | 
+           | Note 2: Yeah, really, please stop.
+        ---'
+        "###)
+    }
+
+    #[test]
+    fn multi_notes_multi_lines() {
+        let source = "apple == orange;";
+        let msg = Report::build(ReportKind::Error, 0..0)
+            .with_config(no_color_and_ascii())
+            .with_message("can't compare apples with oranges")
+            .with_label(Label::new(0..15).with_message("This is a strange comparison"))
+            .with_note("No need to try, they can't be compared.")
+            .with_note("Yeah, really, please stop.\nIt has no resemblance.")
+            .finish()
+            .write_to_string(Source::from(source));
+        assert_snapshot!(msg, @r###"
+        Error: can't compare apples with oranges
+           ,-[<unknown>:1:1]
+           |
+         1 | apple == orange;
+           | ^^^^^^^|^^^^^^^  
+           |        `--------- This is a strange comparison
+           | 
+           | Note 1: No need to try, they can't be compared.
+           | 
+           | Note 2: Yeah, really, please stop.
+           |         It has no resemblance.
+        ---'
+        "###)
+    }
 }
