@@ -2,6 +2,4 @@ mod bad_error_messages;
 mod dbs;
 mod error_messages;
 mod queries;
-mod resolving;
 mod sql;
-mod static_eval;
